{% extends "bee_django_mission/base.html" %}
{% load static %}
{% load bootstrap3 %}
{% block content %}
        <h4>修改{{ line.name }}</h4>
    <form method="post">
        {% csrf_token %}

        {% bootstrap_form form %}
        {% bootstrap_button '提交'%}
    </form>
{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {

        });
    </script>
{% endblock %}